summaryrefslogtreecommitdiff
path: root/include/user/kernel/processmgr.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/user/kernel/processmgr.h')
-rw-r--r--include/user/kernel/processmgr.h48
1 files changed, 24 insertions, 24 deletions
diff --git a/include/user/kernel/processmgr.h b/include/user/kernel/processmgr.h
index 2784d12..8bd2cdd 100644
--- a/include/user/kernel/processmgr.h
+++ b/include/user/kernel/processmgr.h
@@ -8,28 +8,28 @@
extern "C" {
#endif
-enum {
- SCE_KERNEL_PROCESS_PRIORITY_SYSTEM_HIGH = 32,
- SCE_KERNEL_PROCESS_PRIORITY_SYSTEM_DEFAULT = 96,
- SCE_KERNEL_PROCESS_PRIORITY_SYSTEM_LOW = 159
-};
-
-enum {
- SCE_KERNEL_PROCESS_PRIORITY_USER_HIGH = 64,
- SCE_KERNEL_PROCESS_PRIORITY_USER_DEFAULT = 96,
- SCE_KERNEL_PROCESS_PRIORITY_USER_LOW = 127
-};
-
-enum {
+typedef enum SceKernelProcessPrioritySystem {
+ SCE_KERNEL_PROCESS_PRIORITY_SYSTEM_HIGH = 32,
+ SCE_KERNEL_PROCESS_PRIORITY_SYSTEM_DEFAULT = 96,
+ SCE_KERNEL_PROCESS_PRIORITY_SYSTEM_LOW = 159
+} SceKernelProcessPrioritySystem;
+
+typedef enum SceKernelProcessPriorityUser {
+ SCE_KERNEL_PROCESS_PRIORITY_USER_HIGH = 64,
+ SCE_KERNEL_PROCESS_PRIORITY_USER_DEFAULT = 96,
+ SCE_KERNEL_PROCESS_PRIORITY_USER_LOW = 127
+} SceKernelProcessPriorityUser;
+
+typedef enum SceKernelPowerTickType {
/** Cancel all timers */
- SCE_KERNEL_POWER_TICK_DEFAULT = 0,
+ SCE_KERNEL_POWER_TICK_DEFAULT = 0,
/** Cancel automatic suspension timer */
- SCE_KERNEL_POWER_TICK_DISABLE_AUTO_SUSPEND = 1,
+ SCE_KERNEL_POWER_TICK_DISABLE_AUTO_SUSPEND = 1,
/** Cancel OLED-off timer */
- SCE_KERNEL_POWER_TICK_DISABLE_OLED_OFF = 4,
+ SCE_KERNEL_POWER_TICK_DISABLE_OLED_OFF = 4,
/** Cancel OLED dimming timer */
- SCE_KERNEL_POWER_TICK_DISABLE_OLED_DIMMING = 6
-};
+ SCE_KERNEL_POWER_TICK_DISABLE_OLED_DIMMING = 6
+} SceKernelPowerTickType;
/***
* Exit current Process with specified return code
@@ -44,29 +44,29 @@ int sceKernelExitProcess(int res);
/***
* Cancel specified idle timers to prevent entering in power save processing.
*
* @param[in] type - One of ::KernelPowerTickType
*
* @return 0
*/
-int sceKernelPowerTick(int type);
+int sceKernelPowerTick(SceKernelPowerTickType type);
/***
* Locks certain timers from triggering.
*
* @param[in] type - One of ::KernelPowerTickType
*
* @return 0
*/
-int sceKernelPowerLock(int type);
+int sceKernelPowerLock(SceKernelPowerTickType type);
/***
* Unlocks certain timers.
*
* @param[in] type - One of ::KernelPowerTickType
*
* @return 0
*/
-int sceKernelPowerUnlock(int type);
+int sceKernelPowerUnlock(SceKernelPowerTickType type);
/***
* Get the process time of the current process.
@@ -44,29 +44,29 @@ int sceKernelExitProcess(int res);
* Cancel specified idle timers to prevent entering in power save processing.
*
- * @param[in] type - One of ::KernelPowerTickType
+ * @param[in] type - One of ::SceKernelPowerTickType
*
* @return 0
@@ -44,29 +44,29 @@ int sceKernelExitProcess(int res);
* Locks certain timers from triggering.
*
- * @param[in] type - One of ::KernelPowerTickType
+ * @param[in] type - One of ::SceKernelPowerTickType
*
* @return 0
@@ -44,29 +44,29 @@ int sceKernelExitProcess(int res);
* Unlocks certain timers.
*
- * @param[in] type - One of ::KernelPowerTickType
+ * @param[in] type - One of ::SceKernelPowerTickType
*
* @return 0